# SPDX-License-Identifier: Apache-2.0

from flask import Blueprint, g, request, jsonify
from werkzeug.utils import secure_filename

from pyles.db import File
from pyles.files import upload_file
from pyles.user import token_required
from pyles.settings import BASE_URL

bp = Blueprint("files_api", __name__)


@bp.post("/upload")
@token_required
def upload():
    file = request.files.get("file")
    if not file:
        return jsonify({"error": "Missing file"}), 400

    hash, content_type = upload_file(file)
    db_file: File = File.create(
        user=g.user,
        filename=secure_filename(file.filename),
        hash=hash,
        content_type=content_type,
    )

    return jsonify(
        {
            "id": db_file.id,
            "hash": db_file.hash,
            "url": f"{BASE_URL}/{db_file.path}",
        }
    )
